# MLFlow plugin do InXAI
Celem prac jest implementacja pluginu do frameworka [MLFlow](https://mlflow.org/) umożliwiajacego logowanie danych z eksperymentów przeprowadzanych przy pomocy frmamewoka [InXAI](https://github.com/sbobek/inxai).

  * Efektem prac powinien być plugin, pozwalajacy na integrację InXAI z MLFlow
  * Efektem prac powinien być notebook demonstrujący wykorzystanie pluginu
  * Wszystkie dane (zarówno z InXAI i pozostałych mechanizmóœ MLFlow) powinny być możliwe do wyeksportowania do pliku CSV. Tutaj zalecane jest wykorzystanie istniejących mechanizmóœ już zaimplementowanych w MLFLow
  * Efektem prac ma być również dokumentacja i howto
